==> pochy-0.1.9-src.tar.gz: pochy-0.1.9-src/Template.cpp <==
// Template.cpp: CTemplate NX̃Cve[V
//
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "pochy.h"
#include "Template.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// \z/
//////////////////////////////////////////////////////////////////////

CTemplate::CTemplate()
{

}

CTemplate::~CTemplate()
{

}

// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
// start
//void CTemplate::SetCurrentBody(CString body)
void CTemplate::SetBody(CString body)
// end
{
	m_body = body;
}

/*
%d	t
%f	ol
%N	ol̎
%F	ol̖O
%I	ol̃CjV
%s	
%t	
%c	Cc
%a	̃AhX
%r	reply-to
%m	x-mailer
%M	bZ[W{
%Q	ptbZ[W{
%S	signature
%%	%
*/

CString CTemplate::GetString(CMimeDecode *md, CString tmpl)
{
	CString buf;
// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
// start
	CString body;
// end

	for(int i=0; i<tmpl.GetLength(); i++){
		if(tmpl[i] == '%' && (i+1) < tmpl.GetLength()){
			switch(tmpl[i+1]){
// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
// start
			case 'a':
				buf += m_address;
				i++;
				continue;
// end
			case 'd':
				if(md->m_hi.GetDate().IsEmpty()){
					buf += "none";
				}else{
					buf += md->m_hi.GetDate();
				}
				i++;
				continue;
			case 'f':
				if(md->m_hi.GetFrom().IsEmpty()){
					buf += "none";
				}else{
					buf += md->m_hi.GetFrom();
				}
				i++;
				continue;
			case 's':
				if(md->m_hi.GetSubject().IsEmpty()){
					buf += "none";
				}else{
					buf += md->m_hi.GetSubject();
				}
				i++;
				continue;
			case 't':
				if(md->m_hi.GetTo().IsEmpty()){
					buf += "none";
				}else{
					buf += md->m_hi.GetTo();
				}
				i++;
				continue;
			case 'c':
				if(md->m_hi.GetCc().IsEmpty()){
					buf += "none";
				}else{
					buf += md->m_hi.GetCc();
				}
				i++;
				continue;
			case 'r':
				if(md->m_hi.GetReplyTo().IsEmpty()){
					buf += "none";
				}else{
					buf += md->m_hi.GetReplyTo();
				}
				i++;
				continue;
			case 'm':
				if(md->m_hi.GetXmailer().IsEmpty()){
					buf += "none";
				}else{
					buf += md->m_hi.GetXmailer();
				}
				i++;
				continue;
			case 'M':
// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
// start
				buf += m_body;
// end
				i++;
				continue;
			case 'Q':
// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
// start
				body = m_body;
				body.Replace("\r\n","\r\n> ");
				buf += "> "+body+"\r\n";
				i++;
				continue;
			case 'S':
				buf += m_signature;
// end
				i++;
				continue;
			case '%':
				buf += "%";
				i++;
				continue;
			default:
				i++;
				continue;
			}
		}
		buf += tmpl[i];
	}
	return buf;
}

// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
// start
void CTemplate::SetSignature(CString signature)
{
	m_signature = signature;
}

void CTemplate::SetAddress(CString address)
{
	m_address = address;
}
// end

==> pochy-0.2-src.tar.gz: pochy-0.2-src/Template.cpp <==
// Template.cpp: CTemplate NX̃Cve[V
//
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "pochy.h"
#include "Template.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// \z/
//////////////////////////////////////////////////////////////////////

CTemplate::CTemplate()
{

}

CTemplate::~CTemplate()
{

}

void CTemplate::SetBody(CString body)
{
	m_body = body;
}

/*
%d	t
%f	ol
%N	ol̎
%F	ol̖O
%I	ol̃CjV
%s	
%t	
%c	Cc
%a	̃AhX
%r	reply-to
%m	x-mailer
%M	bZ[W{
%Q	ptbZ[W{
%S	signature
%%	%
*/

CString CTemplate::GetString(CMimeDecode *md, CString tmpl)
{
	CString buf;
	CString body;

	for(int i=0; i<tmpl.GetLength(); i++){
		if(tmpl[i] == '%' && (i+1) < tmpl.GetLength()){
			switch(tmpl[i+1]){
			case 'a':
				buf += m_address;
				i++;
				continue;
			case 'd':
				if(md != NULL){
					if(md->m_hi.GetDate().IsEmpty()){
						buf += "none";
					}else{
						buf += md->m_hi.GetDate();
					}
				}
				i++;
				continue;
			case 'f':
				if(md != NULL){
					if(md->m_hi.GetFrom().IsEmpty()){
						buf += "none";
					}else{
						buf += md->m_hi.GetFrom();
					}
				}
				i++;
				continue;
			case 's':
				if(md != NULL){
					if(md->m_hi.GetSubject().IsEmpty()){
						buf += "none";
					}else{
						buf += md->m_hi.GetSubject();
					}
				}
				i++;
				continue;
			case 't':
				if(md != NULL){
					if(md->m_hi.GetTo().IsEmpty()){
						buf += "none";
					}else{
						buf += md->m_hi.GetTo();
					}
				}
				i++;
				continue;
			case 'c':
				if(md != NULL){
					if(md->m_hi.GetCc().IsEmpty()){
						buf += "none";
					}else{
						buf += md->m_hi.GetCc();
					}
				}
				i++;
				continue;
			case 'r':
				if(md != NULL){
					if(md->m_hi.GetReplyTo().IsEmpty()){
						buf += "none";
					}else{
						buf += md->m_hi.GetReplyTo();
					}
				}
				i++;
				continue;
			case 'm':
				if(md != NULL){
					if(md->m_hi.GetXmailer().IsEmpty()){
						buf += "none";
					}else{
						buf += md->m_hi.GetXmailer();
					}
				}
				i++;
				continue;
			case 'M':
				buf += m_body;
				i++;
				continue;
			case 'Q':
				body = m_body;
				body.Replace("\r\n","\r\n> ");
				buf += "> "+body+"\r\n";
				i++;
				continue;
			case 'S':
				buf += m_signature;
				i++;
				continue;
			case '%':
				buf += "%";
				i++;
				continue;
			default:
				i++;
				continue;
			}
		}
		buf += tmpl[i];
	}
	return buf;
}

void CTemplate::SetSignature(CString signature)
{
	m_signature = signature;
}

void CTemplate::SetAddress(CString address)
{
	m_address = address;
}
